@@ -1,10 +1,12 @@
-/* plr/plr--unpackaged--8.3.0.17.sql */
+/* plr/plr--unpackaged--8.4.sql */
 
 ALTER EXTENSION plr ADD type plr_environ_type;
 ALTER EXTENSION plr ADD type r_typename;
 ALTER EXTENSION plr ADD type r_version_type;
 
 ALTER EXTENSION plr ADD function plr_call_handler();
+ALTER EXTENSION plr ADD function plr_inline_handler(internal);
+ALTER EXTENSION plr ADD function plr_validator(oid);
 ALTER EXTENSION plr ADD function plr_version();
 ALTER EXTENSION plr ADD function reload_plr_modules();
 ALTER EXTENSION plr ADD function install_rcmd(text);
